@@ -37,27 +37,33 @@ pub struct Results2 {
 
 impl Results2 {
     pub fn primary(&self) -> &VideoPrimaryInfoRenderer {
-        if let Content::VideoPrimaryInfoRenderer(ret) = &self.contents[0] {
-            ret
-        } else {
-            unreachable!("VideoPrimaryInfoRenderer was not at index 0")
-        }
+        self.contents
+            .iter()
+            .find_map(|x| match x {
+                Content::VideoPrimaryInfoRenderer(ret) => Some(ret),
+                _ => None,
+            })
+            .expect("VideoPrimaryInfoRenderer was not found")
     }
 
     pub fn secondary(&self) -> &VideoSecondaryInfoRenderer {
-        if let Content::VideoSecondaryInfoRenderer(ret) = &self.contents[1] {
-            ret
-        } else {
-            unreachable!("VideoSecondaryInfoRenderer was not at index 1")
-        }
+        self.contents
+            .iter()
+            .find_map(|x| match x {
+                Content::VideoSecondaryInfoRenderer(ret) => Some(ret),
+                _ => None,
+            })
+            .expect("VideoSecondaryInfoRenderer was not found")
     }
 
     pub fn comments(&self) -> Option<&ContinuationItemRenderer> {
-        if let Content::ItemSectionRenderer(ret) = &self.contents[2] {
-            ret.contents.0.continuation_item_renderer.as_ref()
-        } else {
-            unreachable!("ItemSectionRenderer was not at index 2")
-        }
+        self.contents
+            .iter()
+            .find_map(|x| match x {
+                Content::ItemSectionRenderer(ret) => Some(ret),
+                _ => None,
+            })
+            .and_then(|x| x.contents.0.continuation_item_renderer.as_ref())
     }
 }
 
@@ -68,6 +74,7 @@ pub enum Content {
     VideoSecondaryInfoRenderer(VideoSecondaryInfoRenderer),
     ItemSectionRenderer(ItemSectionRenderer),
     MerchandiseShelfRenderer {},
+    TicketShelfRenderer {},
 }
 
 #[derive(Clone, Deserialize)]
@@ -124,9 +131,9 @@ pub struct MenuRenderer {
 impl MenuRenderer {
     fn like_button(&self) -> Option<&ToggleButtonRenderer> {
         self.top_level_buttons.iter().find_map(|x| match x {
-            &TopLevelButton::ToggleButtonRenderer(ref button) => Some(button),
-            &TopLevelButton::ButtonRenderer {} => None,
-            &TopLevelButton::DownloadButtonRenderer {} => None,
+            TopLevelButton::ToggleButtonRenderer(ref button) => Some(button),
+            TopLevelButton::ButtonRenderer {} => None,
+            TopLevelButton::DownloadButtonRenderer {} => None,
         })
     }
 }
