@@ -1,5 +1,6 @@
 use std::time::Duration;
 
+use crate::error::Youtube;
 use reqwest::Url;
 use serde::Deserialize;
 
@@ -127,17 +128,21 @@ pub struct PlayabilityStatus {
 
 impl PlayabilityStatus {
     fn as_error(&self) -> crate::error::Youtube {
-        use crate::error::Youtube;
-
         match self.reason.as_str() {
             "This video is unavailable" => Youtube::NotFound,
             "This video is no longer available because the YouTube account associated with this video has been terminated." => Youtube::AccountTerminated,
+            "The YouTube account associated with this video has been terminated due to multiple third-party notifications of copyright infringement." => Youtube::AccountTerminated,
             "This video has been removed by the uploader" => Youtube::RemovedByUploader,
             "This video has been removed for violating YouTube's policy on nudity or sexual content" => Youtube::NudityOrSexualContentViolation,
             "This video is private" => Youtube::Private,
             "This video has been removed for violating YouTube's Terms of Service." => Youtube::TermsOfServiceViolation,
+            "This video has been removed for violating YouTube's Terms of Service" => Youtube::TermsOfServiceViolation,
+            "This video has been removed for violating YouTube's Community Guidelines" => Youtube::CommunityGuidelineViolation,
+            "This video is no longer available due to a privacy claim by a third party" => Youtube::PrivacyClaim,
             "This video requires payment to watch." => Youtube::PurchaseRequired,
             "This video may be inappropriate for some users." => Youtube::AgeRestricted,
+            "This video is not available in your country" => Youtube::GeoRestricted,
+            "This video is no longer available because the uploader has closed their YouTube account." => Youtube::AccountDeleted,
             copyright if copyright.starts_with("This video is no longer available due to a copyright claim by") => {
                 let who = copyright
                     .strip_prefix("This video is no longer available due to a copyright claim by ")
